@@ -2,7 +2,7 @@
 from __future__ import absolute_import
 from __future__ import with_statement
 
-if __name__ == "__main__" and __package__ is None:
+if __name__ == "__main__" and globals().get("__package__") is None:
     __package__ = "celery.bin.celeryev"
 
 import os
