@@ -1,9 +1,14 @@
 # -*- coding: utf-8 -*-
 from __future__ import absolute_import
 
+import os
 import platform
 import signal as _signal
 
+
+from ... import platforms
+from ... import signals
+from ...app import app_or_default
 from ..base import BasePool
 from .pool import Pool, RUN
 
@@ -15,32 +20,51 @@ if platform.system() == "Windows":  # pragma: no cover
 else:
     from os import kill as _kill                 # noqa
 
+#: List of signals to reset when a child process starts.
+WORKER_SIGRESET = frozenset(["SIGTERM",
+                             "SIGHUP",
+                             "SIGTTIN",
+                             "SIGTTOU",
+                             "SIGUSR1"])
+
+#: List of signals to ignore when a child process starts.
+WORKER_SIGIGNORE = frozenset(["SIGINT"])
+
+
+def process_initializer(app, hostname):
+    """Initializes the process so it can be used to process tasks."""
+    app = app_or_default(app)
+    app.set_current()
+    platforms.signals.reset(*WORKER_SIGRESET)
+    platforms.signals.ignore(*WORKER_SIGIGNORE)
+    platforms.set_mp_process_title("celeryd", hostname=hostname)
+    # This is for Windows and other platforms not supporting
+    # fork(). Note that init_worker makes sure it's only
+    # run once per process.
+    app.log.setup(int(os.environ.get("CELERY_LOG_LEVEL", 0)),
+                  os.environ.get("CELERY_LOG_FILE") or None,
+                  bool(os.environ.get("CELERY_LOG_REDIRECT", False)),
+                  str(os.environ.get("CELERY_LOG_REDIRECT_LEVEL")))
+    app.loader.init_worker()
+    app.loader.init_worker_process()
+    signals.worker_process_init.send(sender=None)
+
 
 class TaskPool(BasePool):
-    """Process Pool for processing tasks in parallel.
-
-    :param processes: see :attr:`processes`.
-    :param logger: see :attr:`logger`.
-
-
-    .. attribute:: limit
-
-        The number of processes that can run simultaneously.
-
-    .. attribute:: logger
-
-        The logger used for debugging.
-
-    """
+    """Multiprocessing Pool implementation."""
     Pool = Pool
 
+    requires_mediator = True
+
     def on_start(self):
         """Run the task pool.
 
         Will pre-fork all workers so they're ready to accept tasks.
 
         """
-        self._pool = self.Pool(processes=self.limit, **self.options)
+        self._pool = self.Pool(processes=self.limit,
+                               initializer=process_initializer,
+                               **self.options)
         self.on_apply = self._pool.apply_async
 
     def on_stop(self):
@@ -65,6 +89,9 @@ class TaskPool(BasePool):
     def shrink(self, n=1):
         return self._pool.shrink(n)
 
+    def restart(self):
+        self._pool.restart()
+
     def _get_info(self):
         return {"max-concurrency": self.limit,
                 "processes": [p.pid for p in self._pool._pool],
