@@ -5,7 +5,7 @@
 
     Custom types and data structures.
 
-    :copyright: (c) 2009 - 2011 by Ask Solem.
+    :copyright: (c) 2009 - 2012 by Ask Solem.
     :license: BSD, see LICENSE for more details.
 
 """
@@ -16,12 +16,189 @@ import sys
 import time
 import traceback
 
+from collections import defaultdict
 from itertools import chain
 from threading import RLock
 
+from kombu.utils.limits import TokenBucket  # noqa
+
+from .utils import uniq
 from .utils.compat import UserDict, OrderedDict
 
 
+class CycleError(Exception):
+    """A cycle was detected in an acyclic graph."""
+
+
+class DependencyGraph(object):
+    """A directed acyclic graph of objects and their dependencies.
+
+    Supports a robust topological sort
+    to detect the order in which they must be handled.
+
+    Takes an optional iterator of ``(obj, dependencies)``
+    tuples to build the graph from.
+
+    .. warning::
+
+        Does not support cycle detection.
+
+    """
+
+    def __init__(self, it=None):
+        self.adjacent = {}
+        if it is not None:
+            self.update(it)
+
+    def add_arc(self, obj):
+        """Add an object to the graph."""
+        self.adjacent[obj] = []
+
+    def add_edge(self, A, B):
+        """Add an edge from object ``A`` to object ``B``
+        (``A`` depends on ``B``)."""
+        self[A].append(B)
+
+    def topsort(self):
+        """Sort the graph topologically.
+
+        :returns: a list of objects in the order
+            in which they must be handled.
+
+        """
+        graph = DependencyGraph()
+        components = self._tarjan72()
+
+        NC = dict((node, component)
+                    for component in components
+                        for node in component)
+        for component in components:
+            graph.add_arc(component)
+        for node in self:
+            node_c = NC[node]
+            for successor in self[node]:
+                successor_c = NC[successor]
+                if node_c != successor_c:
+                    graph.add_edge(node_c, successor_c)
+        return [t[0] for t in graph._khan62()]
+
+    def valency_of(self, obj):
+        """Returns the velency (degree) of a vertex in the graph."""
+        l = [len(self[obj])]
+        for node in self[obj]:
+            l.append(self.valency_of(node))
+        return sum(l)
+
+    def update(self, it):
+        """Update the graph with data from a list
+        of ``(obj, dependencies)`` tuples."""
+        tups = list(it)
+        for obj, _ in tups:
+            self.add_arc(obj)
+        for obj, deps in tups:
+            for dep in deps:
+                self.add_edge(obj, dep)
+
+    def edges(self):
+        """Returns generator that yields for all edges in the graph."""
+        return (obj for obj, adj in self.iteritems() if adj)
+
+    def _khan62(self):
+        """Khans simple topological sort algorithm from '62
+
+        See http://en.wikipedia.org/wiki/Topological_sorting
+
+        """
+        count = defaultdict(lambda: 0)
+        result = []
+
+        for node in self:
+            for successor in self[node]:
+                count[successor] += 1
+        ready = [node for node in self if not count[node]]
+
+        while ready:
+            node = ready.pop()
+            result.append(node)
+
+            for successor in self[node]:
+                count[successor] -= 1
+                if count[successor] == 0:
+                    ready.append(successor)
+        result.reverse()
+        return result
+
+    def _tarjan72(self):
+        """Tarjan's algorithm to find strongly connected components.
+
+        See http://bit.ly/vIMv3h.
+
+        """
+        result, stack, low = [], [], {}
+
+        def visit(node):
+            if node in low:
+                return
+            num = len(low)
+            low[node] = num
+            stack_pos = len(stack)
+            stack.append(node)
+
+            for successor in self[node]:
+                visit(successor)
+                low[node] = min(low[node], low[successor])
+
+            if num == low[node]:
+                component = tuple(stack[stack_pos:])
+                stack[stack_pos:] = []
+                result.append(component)
+                for item in component:
+                    low[item] = len(self)
+
+        for node in self:
+            visit(node)
+
+        return result
+
+    def to_dot(self, fh, ws=" " * 4):
+        """Convert the graph to DOT format.
+
+        :param fh: A file, or a file-like object to write the graph to.
+
+        """
+        fh.write("digraph dependencies {\n")
+        for obj, adjacent in self.iteritems():
+            if not adjacent:
+                fh.write(ws + '"%s"\n' % (obj, ))
+            for req in adjacent:
+                fh.write(ws + '"%s" -> "%s"\n' % (obj, req))
+        fh.write("}\n")
+
+    def __iter__(self):
+        return self.adjacent.iterkeys()
+
+    def __getitem__(self, node):
+        return self.adjacent[node]
+
+    def __len__(self):
+        return len(self.adjacent)
+
+    def _iterate_items(self):
+        return self.adjacent.iteritems()
+    items = iteritems = _iterate_items
+
+    def __repr__(self):
+        return '\n'.join(self.repr_node(N) for N in self)
+
+    def repr_node(self, obj, level=1):
+        output = ["%s(%s)" % (obj, self.valency_of(obj))]
+        for other in self[obj]:
+            d = "%s(%s)" % (other, self.valency_of(other))
+            output.append('     ' * level + d)
+            output.extend(self.repr_node(other, level + 1).split('\n')[1:])
+        return '\n'.join(output)
+
+
 class AttributeDictMixin(object):
     """Adds attribute access to mappings.
 
@@ -86,7 +263,7 @@ class DictAttribute(object):
         return vars(self.obj).iteritems()
     iteritems = _iterate_items
 
-    if sys.version_info >= (3, 0):
+    if sys.version_info >= (3, 0):  # pragma: no cover
         items = _iterate_items
     else:
 
@@ -157,15 +334,15 @@ class ConfigurationView(AttributeDictMixin):
         return chain(*[op(d) for d in reversed(self._order)])
 
     def _iterate_keys(self):
-        return self._iter(lambda d: d.iterkeys())
+        return uniq(self._iter(lambda d: d.iterkeys()))
     iterkeys = _iterate_keys
 
     def _iterate_items(self):
-        return self._iter(lambda d: d.iteritems())
+        return ((key, self[key]) for key in self)
     iteritems = _iterate_items
 
     def _iterate_values(self):
-        return self._iter(lambda d: d.itervalues())
+        return (self[key] for key in self)
     itervalues = _iterate_values
 
     def keys(self):
@@ -191,20 +368,54 @@ class _Frame(object):
     def __init__(self, frame):
         self.f_globals = {
             "__file__": frame.f_globals.get("__file__", "__main__"),
+            "__name__": frame.f_globals.get("__name__"),
+            "__loader__": frame.f_globals.get("__loader__"),
         }
+        self.f_locals = fl = {}
+        try:
+            fl["__traceback_hide__"] = frame.f_locals["__traceback_hide__"]
+        except KeyError:
+            pass
         self.f_code = self.Code(frame.f_code)
+        self.f_lineno = frame.f_lineno
+
+
+class _Object(object):
+
+    def __init__(self, **kw):
+        [setattr(self, k, v) for k, v in kw.iteritems()]
+
+
+class _Truncated(object):
+
+    def __init__(self):
+        self.tb_lineno = -1
+        self.tb_frame = _Object(
+                f_globals={"__file__": "",
+                           "__name__": "",
+                           "__loader__": None},
+                f_fileno=None,
+                f_code=_Object(co_filename="...",
+                               co_name="[rest of traceback truncated]"),
+        )
+        self.tb_next = None
 
 
 class Traceback(object):
     Frame = _Frame
 
-    def __init__(self, tb):
+    tb_frame = tb_lineno = tb_next = None
+    max_frames = sys.getrecursionlimit() / 8
+
+    def __init__(self, tb, max_frames=None, depth=0):
+        limit = self.max_frames = max_frames or self.max_frames
         self.tb_frame = self.Frame(tb.tb_frame)
         self.tb_lineno = tb.tb_lineno
-        if tb.tb_next is None:
-            self.tb_next = None
-        else:
-            self.tb_next = Traceback(tb.tb_next)
+        if tb.tb_next is not None:
+            if depth <= limit:
+                self.tb_next = Traceback(tb.tb_next, limit, depth + 1)
+            else:
+                self.tb_next = _Truncated()
 
 
 class ExceptionInfo(object):
@@ -227,10 +438,14 @@ class ExceptionInfo(object):
     #: String representation of the traceback.
     traceback = None
 
-    def __init__(self, exc_info):
+    #: Set to true if this is an internal error.
+    internal = False
+
+    def __init__(self, exc_info, internal=False):
         self.type, self.exception, tb = exc_info
         self.tb = Traceback(tb)
         self.traceback = ''.join(traceback.format_exception(*exc_info))
+        self.internal = internal
 
     def __str__(self):
         return self.traceback
@@ -294,7 +509,8 @@ class LimitedSet(object):
         if isinstance(other, self.__class__):
             self._data.update(other._data)
         else:
-            self._data.update(other)
+            for obj in other:
+                self.add(obj)
 
     def as_dict(self):
         return self._data
@@ -336,7 +552,7 @@ class LRUCache(UserDict):
     def __getitem__(self, key):
         with self.mutex:
             value = self[key] = self.data.pop(key)
-            return value
+        return value
 
     def keys(self):
         # userdict.keys in py3k calls __getitem__
@@ -359,7 +575,7 @@ class LRUCache(UserDict):
         return self.data.iterkeys()
 
     def _iterate_items(self):
-        for k in self.data:
+        for k in self:
             try:
                 yield (k, self.data[k])
             except KeyError:
@@ -367,67 +583,17 @@ class LRUCache(UserDict):
     iteritems = _iterate_items
 
     def _iterate_values(self):
-        for k in self.data:
+        for k in self:
             try:
                 yield self.data[k]
-            except KeyError:
+            except KeyError:  # pragma: no cover
                 pass
     itervalues = _iterate_values
 
-
-class TokenBucket(object):
-    """Token Bucket Algorithm.
-
-    See http://en.wikipedia.org/wiki/Token_Bucket
-    Most of this code was stolen from an entry in the ASPN Python Cookbook:
-    http://code.activestate.com/recipes/511490/
-
-    .. admonition:: Thread safety
-
-        This implementation may not be thread safe.
-
-    """
-
-    #: The rate in tokens/second that the bucket will be refilled
-    fill_rate = None
-
-    #: Maximum number of tokensin the bucket.
-    capacity = 1
-
-    #: Timestamp of the last time a token was taken out of the bucket.
-    timestamp = None
-
-    def __init__(self, fill_rate, capacity=1):
-        self.capacity = float(capacity)
-        self._tokens = capacity
-        self.fill_rate = float(fill_rate)
-        self.timestamp = time.time()
-
-    def can_consume(self, tokens=1):
-        """Returns :const:`True` if `tokens` number of tokens can be consumed
-        from the bucket."""
-        if tokens <= self._get_tokens():
-            self._tokens -= tokens
-            return True
-        return False
-
-    def expected_time(self, tokens=1):
-        """Returns the expected time in seconds when a new token should be
-        available.
-
-        .. admonition:: Warning
-
-            This consumes a token from the bucket.
-
-        """
-        _tokens = self._get_tokens()
-        tokens = max(tokens, _tokens)
-        return (tokens - _tokens) / self.fill_rate
-
-    def _get_tokens(self):
-        if self._tokens < self.capacity:
-            now = time.time()
-            delta = self.fill_rate * (now - self.timestamp)
-            self._tokens = min(self.capacity, self._tokens + delta)
-            self.timestamp = now
-        return self._tokens
+    def incr(self, key, delta=1):
+        with self.mutex:
+            # this acts as memcached does- store as a string, but return a
+            # integer as long as it exists and we can cast it
+            newval = int(self.data.pop(key)) + delta
+            self[key] = str(newval)
+        return newval
