@@ -25,12 +25,14 @@ import traceback
 
 from warnings import warn
 
+from kombu.utils import kwdict
+
 from .. import app as app_module
 from .. import current_app
 from .. import states, signals
+from ..app.task import BaseTask
 from ..datastructures import ExceptionInfo
 from ..exceptions import RetryTaskError
-from ..registry import tasks
 from ..utils.serialization import get_pickleable_exception
 
 send_prerun = signals.task_prerun.send
@@ -44,6 +46,27 @@ FAILURE = states.FAILURE
 EXCEPTION_STATES = states.EXCEPTION_STATES
 
 
+def mro_lookup(cls, attr, stop=()):
+    """Returns the first node by MRO order that defines an attribute.
+
+    :keyword stop: A list of types that if reached will stop the search.
+
+    :returns None: if the attribute was not found.
+
+    """
+    for node in cls.mro():
+        if node in stop:
+            return
+        if attr in node.__dict__:
+            return node
+
+
+def defines_custom_call(task):
+    """Returns true if the task or one of its bases
+    defines __call__ (excluding the one in BaseTask)."""
+    return mro_lookup(task.__class__, "__call__", stop=(BaseTask, object))
+
+
 class TraceInfo(object):
     __slots__ = ("state", "retval", "exc_info",
                  "exc_type", "exc_value", "tb", "strtb")
@@ -107,7 +130,11 @@ class TraceInfo(object):
 
 def build_tracer(name, task, loader=None, hostname=None, store_errors=True,
         Info=TraceInfo, eager=False, propagate=False):
-    task = task or tasks[name]
+    # If the task doesn't define a custom __call__ method
+    # we optimize it away by simply calling the run method directly,
+    # saving the extra method call and a line less in the stack trace.
+    fun = task if defines_custom_call(task) else task.run
+
     loader = loader or current_app.loader
     backend = task.backend
     ignore_result = task.ignore_result
@@ -135,6 +162,7 @@ def build_tracer(name, task, loader=None, hostname=None, store_errors=True,
 
     def trace_task(uuid, args, kwargs, request=None):
         R = I = None
+        kwargs = kwdict(kwargs)
         try:
             _tls.current_task = task
             update_request(request or {}, args=args,
@@ -150,7 +178,7 @@ def build_tracer(name, task, loader=None, hostname=None, store_errors=True,
 
                 # -*- TRACE -*-
                 try:
-                    R = retval = task(*args, **kwargs)
+                    R = retval = fun(*args, **kwargs)
                     state, einfo = SUCCESS, None
                 except RetryTaskError, exc:
                     I = Info(RETRY, exc, sys.exc_info())
@@ -195,7 +223,7 @@ def build_tracer(name, task, loader=None, hostname=None, store_errors=True,
                     except Exception, exc:
                         logger = current_app.log.get_default_logger()
                         logger.error("Process cleanup failed: %r", exc,
-                                     exc_info=sys.exc_info())
+                                     exc_info=True)
         except Exception, exc:
             if eager:
                 raise
