@@ -5,7 +5,7 @@
 
     The task implementation has been moved to :mod:`celery.app.task`.
 
-    :copyright: (c) 2009 - 2011 by Ask Solem.
+    :copyright: (c) 2009 - 2012 by Ask Solem.
     :license: BSD, see LICENSE for more details.
 
 """
@@ -14,27 +14,11 @@ from __future__ import absolute_import
 from .. import current_app
 from ..app.task import Context, TaskType, BaseTask  # noqa
 from ..schedules import maybe_schedule
-from ..utils import deprecated, timeutils
+from ..utils import timeutils
 
 Task = current_app.Task
 
 
-@deprecated("Importing TaskSet from celery.task.base",
-            alternative="Use celery.task.TaskSet instead.",
-            removal="2.4")
-def TaskSet(*args, **kwargs):
-    from celery.task.sets import TaskSet
-    return TaskSet(*args, **kwargs)
-
-
-@deprecated("Importing subtask from celery.task.base",
-            alternative="Use celery.task.subtask instead.",
-            removal="2.4")
-def subtask(*args, **kwargs):
-    from celery.task.sets import subtask
-    return subtask(*args, **kwargs)
-
-
 class PeriodicTask(Task):
     """A periodic task is a task that behaves like a :manpage:`cron` job.
 
