@@ -1,6 +1,8 @@
+from __future__ import absolute_import
+
 import time
 
-from celery.decorators import task
+from celery.task import task
 from celery.task.sets import subtask
 
 
