@@ -1,3 +1,6 @@
+from __future__ import absolute_import
+from __future__ import with_statement
+
 import logging
 import sys
 
@@ -98,16 +101,22 @@ class test_Beat(AppCase):
         clock = MockService()
         MockService.in_sync = False
         handlers = self.psig(b.install_sync_handler, clock)
-        self.assertRaises(SystemExit, handlers["SIGINT"],
-                          "SIGINT", object())
+        with self.assertRaises(SystemExit):
+            handlers["SIGINT"]("SIGINT", object())
         self.assertTrue(MockService.in_sync)
         MockService.in_sync = False
 
     def test_setup_logging(self):
+        try:
+            # py3k
+            delattr(sys.stdout, "logger")
+        except AttributeError:
+            pass
         b = beatapp.Beat()
         b.redirect_stdouts = False
         b.setup_logging()
-        self.assertRaises(AttributeError, getattr, sys.stdout, "logger")
+        with self.assertRaises(AttributeError):
+            sys.stdout.logger
 
     @redirect_stdouts
     def test_logs_errors(self, stdout, stderr):
