@@ -4,15 +4,14 @@ import operator
 
 from celery.concurrency import solo
 from celery.utils import noop
-from celery.tests.utils import unittest
+from celery.tests.utils import Case
 
 
-class test_solo_TaskPool(unittest.TestCase):
+class test_solo_TaskPool(Case):
 
     def test_on_start(self):
         x = solo.TaskPool()
         x.on_start()
-        self.assertTrue(x.pid)
 
     def test_on_apply(self):
         x = solo.TaskPool()
