@@ -2,7 +2,7 @@ from __future__ import absolute_import
 
 from nose import SkipTest
 
-from celery.tests.utils import unittest
+from celery.tests.utils import Case
 
 
 class MockWindow(object):
@@ -11,7 +11,7 @@ class MockWindow(object):
         return self.y, self.x
 
 
-class TestCursesDisplay(unittest.TestCase):
+class TestCursesDisplay(Case):
 
     def setUp(self):
         try:
