@@ -2,15 +2,12 @@ from __future__ import absolute_import
 from __future__ import with_statement
 
 import anyjson
-import warnings
 
-from celery import registry
 from celery.app import app_or_default
 from celery.task import Task
 from celery.task.sets import subtask, TaskSet
 
-from celery.tests.utils import unittest
-from celery.tests.compat import catch_warnings
+from celery.tests.utils import Case
 
 
 class MockTask(Task):
@@ -28,7 +25,7 @@ class MockTask(Task):
         return (args, kwargs, options)
 
 
-class test_subtask(unittest.TestCase):
+class test_subtask(Case):
 
     def test_behaves_like_type(self):
         s = subtask("tasks.add", (2, 2), {"cache": True},
@@ -101,28 +98,7 @@ class test_subtask(unittest.TestCase):
         self.assertDictEqual(dict(cls(*args)), dict(s))
 
 
-class test_TaskSet(unittest.TestCase):
-
-    def test_interface__compat(self):
-        warnings.resetwarnings()
-        with catch_warnings(record=True) as log:
-            ts = TaskSet(MockTask, [[(2, 2)], [(4, 4)], [(8, 8)]])
-            self.assertListEqual(ts.tasks,
-                                 [MockTask.subtask((i, i))
-                                    for i in (2, 4, 8)])
-            self.assertIn("Using this invocation of TaskSet is deprecated",
-                          log[0].message.args[0])
-            log[:] = []
-            self.assertEqual(ts.task, registry.tasks[MockTask.name])
-            self.assertTrue(log)
-            self.assertIn("TaskSet.task is deprecated",
-                          log[0].message.args[0])
-
-            log[:] = []
-            self.assertEqual(ts.task_name, MockTask.name)
-            self.assertTrue(log)
-            self.assertIn("TaskSet.task_name is deprecated",
-                          log[0].message.args[0])
+class test_TaskSet(Case):
 
     def test_task_arg_can_be_iterable__compat(self):
         ts = TaskSet([MockTask.subtask((i, i))
