@@ -554,14 +554,14 @@ class test_Consumer(Case):
         l.event_dispatcher = Mock()
         l.connection_errors = (socket.error, )
         l.logger = Mock()
-        m.ack = Mock()
-        m.ack.side_effect = socket.error("foo")
+        m.reject = Mock()
+        m.reject.side_effect = socket.error("foo")
         with self.assertWarnsRegex(RuntimeWarning, r'unknown message'):
             self.assertFalse(l.receive_message(m.decode(), m))
         with self.assertRaises(Empty):
             self.ready_queue.get_nowait()
         self.assertTrue(self.eta_schedule.empty())
-        m.ack.assert_called_with()
+        m.reject.assert_called_with()
         self.assertTrue(l.logger.critical.call_count)
 
     def test_receieve_message_eta(self):
