@@ -6,7 +6,7 @@
     Backward compatible implementations of features
     only available in newer Python versions.
 
-    :copyright: (c) 2009 - 2011 by Ask Solem.
+    :copyright: (c) 2009 - 2012 by Ask Solem.
     :license: BSD, see LICENSE for more details.
 
 """
@@ -15,6 +15,11 @@ from __future__ import absolute_import
 ############## py3k #########################################################
 import sys
 
+try:
+    reload = reload                     # noqa
+except NameError:
+    from imp import reload              # noqa
+
 try:
     from UserList import UserList       # noqa
 except ImportError:
